@@ -6,6 +6,7 @@
 # Copyright (C) 2008-2009  Gary Burton
 # Copyright (C) 2009-2012  Doug Blank <doug.blank@gmail.com>
 # Copyright (C) 2011       Tim G L Lyons
+# Copyright (C) 2015-      Serge Noiraud
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -148,6 +149,7 @@ register('behavior.min-generation-years', 13)
 register('behavior.owner-warn', False)
 register('behavior.pop-plugin-status', False)
 register('behavior.recent-export-type', 3)
+register('behavior.runcheck', False)
 register('behavior.spellcheck', False)
 register('behavior.startup', 0)
 register('behavior.surname-guessing', 0)
@@ -155,9 +157,9 @@ register('behavior.translator-needed', True)
 register('behavior.use-tips', False)
 register('behavior.welcome', 100)
 register('behavior.web-search-url', 'http://google.com/#&q=%(text)s')
-register('behavior.addons-url', "https://raw.githubusercontent.com/gramps-project/addons/master/gramps50")
+register('behavior.addons-url', "https://raw.githubusercontent.com/gramps-project/addons/master/gramps51")
 
-register('database.backend', 'bsddb')
+register('database.backend', 'sqlite')
 register('database.compress-backup', True)
 register('database.backup-path', USER_HOME)
 register('database.backup-on-exit', True)
@@ -217,6 +219,7 @@ register('interface.sidebar-text', True)
 register('interface.size-checked', False)
 register('interface.statusbar', 1)
 register('interface.toolbar-on', True)
+register('interface.toolbar-text', False)
 register('interface.view', True)
 register('interface.surname-box-height', 150)
 register('interface.treemodel-cache-size', 1000)
@@ -228,6 +231,8 @@ register('paths.report-directory', USER_HOME)
 register('paths.website-directory', USER_HOME)
 register('paths.website-cms-uri', '')
 register('paths.website-cal-uri', '')
+register('paths.website-extra-page-uri', '')
+register('paths.website-extra-page-name', '')
 register('paths.quick-backup-directory', USER_HOME)
 register('paths.quick-backup-filename',
          "%(filename)s_%(year)d-%(month)02d-%(day)02d.%(extension)s")
@@ -236,7 +241,6 @@ register('preferences.quick-backup-include-mode', False)
 register('preferences.date-format', 0)
 register('preferences.calendar-format-report', 0)
 register('preferences.cprefix', 'C%04d')
-register('preferences.alternate-fonthandler', False)
 register('preferences.default-source', False)
 register('preferences.tag-on-import', False)
 register('preferences.tag-on-import-format', _("Imported %Y/%m/%d %H:%M:%S"))
@@ -278,6 +282,10 @@ register('colors.female-dead', ['#feccf0', '#3a292b'])
 register('colors.unknown-alive', ['#f3dbb6', '#75507B'])
 register('colors.unknown-dead', ['#f3dbb6', '#35103b'])
 register('colors.family', ['#eeeeee', '#454545'])
+register('colors.family-married', ['#eeeeee', '#454545'])
+register('colors.family-unmarried', ['#eeeeee', '#454545'])
+register('colors.family-civil-union', ['#eeeeee', '#454545'])
+register('colors.family-unknown', ['#eeeeee', '#454545'])
 register('colors.family-divorced', ['#ffdede', '#5c3636'])
 register('colors.home-person', ['#bbe68a', '#304918'])
 register('colors.border-male-alive', ['#1f4986', '#171d26'])
@@ -302,6 +310,11 @@ register('researcher.researcher-state', '')
 register('plugin.hiddenplugins', [])
 register('plugin.addonplugins', [])
 
+register('utf8.in-use', False)
+register('utf8.available-fonts', [])
+register('utf8.selected-font', "")
+register('utf8.death-symbol', 13)
+
 if __debug__: # enable a simple CLI test to see if the datestrings exist
     register('test.january', _("localized lexeme inflections||January"))
 
