@@ -303,27 +303,6 @@ class DbLoader(CLIDbLoader):
         self._end_progress()
         return True
 
-#-------------------------------------------------------------------------
-#
-# default dir selection
-#
-#-------------------------------------------------------------------------
-def get_default_dir():
-    # Suggested folder: try last open file, last import, last export,
-    # then home.
-    default_dir = os.path.dirname(config.get('paths.recent-file'))
-    if default_dir:
-        default_dir += os.path.sep
-        if len(default_dir)<=1:
-            default_dir = config.get('paths.recent-import-dir')
-        if len(default_dir)<=1:
-            default_dir = config.get('paths.recent-export-dir')
-        if len(default_dir)<=1:
-            default_dir = '~/'
-    else:
-        default_dir = "~/"
-    return default_dir
-
 #-------------------------------------------------------------------------
 #
 # FileChooser filters: what to show in the file chooser
@@ -338,6 +317,13 @@ def add_all_files_filter(chooser):
     mime_filter.add_pattern('*')
     chooser.add_filter(mime_filter)
 
+
+def icase(ext):
+    """
+    Return a glob reresenting a case insensitive file extension.
+    """
+    return ''.join(['[{}{}]'.format(s.lower(), s.upper()) for s in ext])
+
 #-------------------------------------------------------------------------
 #
 # Format selectors: explictly set the format of the file
@@ -467,20 +453,13 @@ class GrampsImportFileDialog(ManagedWindow):
             file_filter = Gtk.FileFilter()
             name = "%s (.%s)" % (plugin.get_name(), plugin.get_extension())
             file_filter.set_name(name)
-            file_filter.add_pattern("*.%s" % plugin.get_extension())
-            file_filter.add_pattern(plugin.get_extension().capitalize())
+            file_filter.add_pattern("*.%s" % icase(plugin.get_extension()))
             import_dialog.add_filter(file_filter)
 
         (box, type_selector) = format_maker()
         import_dialog.set_extra_widget(box)
 
-        # Suggested folder: try last open file, import, then last export,
-        # then home.
-        default_dir = config.get('paths.recent-import-dir')
-        if len(default_dir)<=1:
-            default_dir = get_default_dir()
-
-        import_dialog.set_current_folder(default_dir)
+        import_dialog.set_current_folder(config.get('paths.recent-import-dir'))
         while True:
             # the import_dialog.run() makes it modal, so any change to that
             # line would require the ManagedWindow.__init__ to be changed also
