@@ -36,7 +36,7 @@ from gi.repository import Gtk
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from ... import widgets
@@ -44,9 +44,9 @@ from gramps.gen.lib import Event, EventType, Family, FamilyRelType
 from .. import build_filter_model
 from . import SidebarFilter
 from gramps.gen.filters import GenericFilterFactory, rules
-from gramps.gen.filters.rules.family import (RegExpIdOf, RegExpFatherName, 
-                                             RegExpMotherName, RegExpChildName, 
-                                             HasEvent, HasRelType, HasTag, 
+from gramps.gen.filters.rules.family import (RegExpIdOf, RegExpFatherName,
+                                             RegExpMotherName, RegExpChildName,
+                                             HasEvent, HasRelType, HasTag,
                                              HasNoteRegexp, MatchesFilter)
 
 GenericFamilyFilter = GenericFilterFactory('Family')
@@ -63,27 +63,35 @@ class FamilySidebarFilter(SidebarFilter):
         self.filter_father = widgets.BasicEntry()
         self.filter_mother = widgets.BasicEntry()
         self.filter_child = widgets.BasicEntry()
-        
+
         self.filter_event = Event()
         self.filter_event.set_type((EventType.CUSTOM, ''))
         self.etype = Gtk.ComboBox(has_entry=True)
+        if dbstate.is_open():
+            self.custom_types = dbstate.db.get_event_types()
+        else:
+            self.custom_types = []
 
-        self.family_stub = Family()
-        self.family_stub.set_relationship((FamilyRelType.CUSTOM, ''))
-        self.rtype = Gtk.ComboBox(has_entry=True)
-        self.custom_types = dbstate.db.get_family_relation_types()
-        
         self.event_menu = widgets.MonitoredDataType(
             self.etype,
             self.filter_event.set_type,
-            self.filter_event.get_type)
+            self.filter_event.get_type,
+            custom_values=self.custom_types)
+
+        self.filter_family = Family()
+        self.filter_family.set_relationship((FamilyRelType.CUSTOM, ''))
+        self.rtype = Gtk.ComboBox(has_entry=True)
+        if dbstate.is_open():
+            self.custom_types = dbstate.db.get_family_relation_types()
+        else:
+            self.custom_types = []
 
         self.rel_menu = widgets.MonitoredDataType(
             self.rtype,
-            self.family_stub.set_relationship,
-            self.family_stub.get_relationship,
+            self.filter_family.set_relationship,
+            self.filter_family.get_relationship,
             custom_values=self.custom_types)
-        
+
         self.filter_note = widgets.BasicEntry()
 
         self.filter_regex = Gtk.CheckButton(label=_('Use regular expressions'))
@@ -139,7 +147,7 @@ class FamilySidebarFilter(SidebarFilter):
         child = str(self.filter_child.get_text()).strip()
         note = str(self.filter_note.get_text()).strip()
         etype = self.filter_event.get_type().xml_str()
-        rtype = self.family_stub.get_relationship().xml_str()
+        rtype = self.filter_family.get_relationship().xml_str()
         regex = self.filter_regex.get_active()
         tag = self.tag.get_active() > 0
         generic = self.generic.get_active() > 0
@@ -173,7 +181,7 @@ class FamilySidebarFilter(SidebarFilter):
             if rtype:
                 rule = HasRelType([rtype], use_regex=regex)
                 generic_filter.add_rule(rule)
-                
+
             if note:
                 rule = HasNoteRegexp([note], use_regex=regex)
                 generic_filter.add_rule(rule)
