@@ -231,6 +231,10 @@ class DBAPI(DbGeneric):
         _LOG.debug("    %sDBAPI %s transaction begin for '%s'",
                    "Batch " if transaction.batch else "",
                    hex(id(self)), transaction.get_description())
+        if transaction.batch:
+            # A batch transaction does not store the commits
+            # Aborting the session completely will become impossible.
+            self.abort_possible = False
         self.transaction = transaction
         self.dbapi.begin()
         return transaction
@@ -330,9 +334,11 @@ class DBAPI(DbGeneric):
         """
         Return the defined names that have been assigned to a default grouping.
         """
-        self.dbapi.execute("SELECT name FROM name_group ORDER BY name")
+        self.dbapi.execute("SELECT name, grouping FROM name_group "
+                           "ORDER BY name")
         rows = self.dbapi.fetchall()
-        return [row[0] for row in rows]
+        # not None test below fixes db corrupted by 11011 for export
+        return [row[0] for row in rows if row[1] is not None]
 
     def get_name_group_mapping(self, key):
         """
@@ -341,7 +347,8 @@ class DBAPI(DbGeneric):
         self.dbapi.execute(
             "SELECT grouping FROM name_group WHERE name = ?", [key])
         row = self.dbapi.fetchone()
-        if row:
+        if row and row[0] is not None:
+            # not None test fixes db corrupted by 11011
             return row[0]
         else:
             return key
@@ -566,22 +573,28 @@ class DBAPI(DbGeneric):
         self.dbapi.execute("SELECT grouping FROM name_group WHERE name = ?",
                            [key])
         row = self.dbapi.fetchone()
-        return True if row else False
+        return row and row[0] is not None
 
     def set_name_group_mapping(self, name, grouping):
         """
         Set the default grouping name for a surname.
         """
+        self._txn_begin()
         self.dbapi.execute("SELECT 1 FROM name_group WHERE name = ?",
                            [name])
         row = self.dbapi.fetchone()
-        if row:
+        if row and grouping is not None:
             self.dbapi.execute("UPDATE name_group SET grouping=? "
                                "WHERE name = ?", [grouping, name])
+        elif row and grouping is None:
+            self.dbapi.execute("DELETE FROM name_group WHERE name = ?", [name])
+            grouping = ''
         else:
             self.dbapi.execute(
                 "INSERT INTO name_group (name, grouping) VALUES (?, ?)",
                 [name, grouping])
+        self._txn_commit()
+        self.emit('person-groupname-rebuild', (name, grouping))
 
     def _commit_base(self, obj, obj_key, trans, change_time):
         """
@@ -778,6 +791,7 @@ class DBAPI(DbGeneric):
         Reindex all primary records in the database.
         """
         callback(4)
+        self._txn_begin()
         self.dbapi.execute("DELETE FROM reference")
         primary_table = (
             (self.get_person_cursor, Person),
@@ -809,17 +823,36 @@ class DBAPI(DbGeneric):
                              obj.__class__.__name__,
                              ref_handle,
                              ref_class_name])
+        self._txn_commit()
         callback(5)
 
-    def rebuild_secondary(self, update):
+    def rebuild_secondary(self, callback=None):
         """
         Rebuild secondary indices
         """
+        if self.readonly:
+            return
+
         # First, expand blob to individual fields:
-        self._update_secondary_values()
+        self._txn_begin()
+        index = 1
+        for obj_type in ('Person', 'Family', 'Event', 'Place', 'Repository',
+                         'Source', 'Citation', 'Media', 'Note', 'Tag'):
+            for handle in self.method('get_%s_handles', obj_type)():
+                obj = self.method('get_%s_from_handle', obj_type)(handle)
+                self._update_secondary_values(obj)
+            if callback:
+                callback(index)
+            index += 1
+        self._txn_commit()
+        if callback:
+            callback(11)
+
         # Next, rebuild stats:
         gstats = self.get_gender_stats()
         self.genderStats = GenderStats(gstats)
+        if callback:
+            callback(12)
 
     def _has_handle(self, obj_key, handle):
         table = KEY_TO_NAME_MAP[obj_key]
