@@ -34,7 +34,7 @@
 #
 #------------------------------------------------------------------------
 import logging
-import collections
+from collections import abc
 log = logging.getLogger(".WriteFtree")
 
 #-------------------------------------------------------------------------
@@ -73,7 +73,7 @@ class FtreeWriter:
         self.user = user
         self.option_box = option_box
         # is callback is really callable?
-        if isinstance(self.user.callback, collections.Callable):
+        if isinstance(self.user.callback, abc.Callable):
             self.update = self.update_real
         else:
             self.update = self.update_empty
@@ -82,7 +82,8 @@ class FtreeWriter:
             self.option_box.parse_options()
             self.db = option_box.get_filtered_database(self.db)
 
-        self.plist = [x for x in self.db.iter_person_handles()]
+        self.plist = self.db.get_person_handles()
+        self.plist.sort()
         # the following are used to update the progress meter
         self.total = 2 * len(self.plist)
         self.count = 0
