@@ -40,6 +40,7 @@ Create a relationship graph using Graphviz
 #
 #------------------------------------------------------------------------
 from functools import partial
+import html
 
 #------------------------------------------------------------------------
 #
@@ -115,6 +116,7 @@ class RelGraphReport(Report):
         color_families - Colour to apply to families
         dashed         - Whether to use dashed lines for non-birth relationships
         use_roundedcorners - Whether to use rounded corners for females
+        use_hexagons   - Whether to use hexagons for individuals of unknown gender
         name_format    - Preferred format to display names
         incl_private   - Whether to include private data
         event_choice   - Whether to include dates and/or places
@@ -142,8 +144,10 @@ class RelGraphReport(Report):
         self.includeimg = get_value('includeImages')
         self.imgpos = get_value('imageOnTheSide')
         self.use_roundedcorners = get_value('useroundedcorners')
+        self.use_hexagons = get_value('usehexagons')
         self.adoptionsdashed = get_value('dashed')
         self.show_families = get_value('showfamily')
+        self.show_family_leaves = get_value('show_family_leaves')
         self.use_subgraphs = get_value('usesubgraphs')
         self.event_choice = get_value('event_choice')
         self.occupation = get_value('occupation')
@@ -373,13 +377,18 @@ class RelGraphReport(Report):
                     if family is None:
                         continue
                     if fam_handle not in families_done:
-                        families_done.add(fam_handle)
+                        if not self.show_family_leaves:
+                            family_members = {family.father_handle, family.mother_handle}.union(
+                                child_ref.ref for child_ref in family.child_ref_list) - {None}
+                            if len(family_members.intersection(person_handles)) < 2:
+                                continue
                         self.__add_family(fam_handle)
+                        families_done.add(fam_handle)
                     # If subgraphs are not chosen then each parent is linked
                     # separately to the family. This gives Graphviz greater
                     # control over the layout of the whole graph but
                     # may leave spouses not positioned together.
-                    if not self.use_subgraphs:
+                    if not self.use_subgraphs and fam_handle in families_done:
                         self.doc.add_link(p_id, family.get_gramps_id(), "",
                                           self.arrowheadstyle,
                                           self.arrowtailstyle)
@@ -488,13 +497,38 @@ class RelGraphReport(Report):
             self.doc.start_subgraph(fam_id)
             f_handle = fam.get_father_handle()
             m_handle = fam.get_mother_handle()
-            if f_handle:
+            if f_handle and m_handle:
+                father = self._db.get_person_from_handle(f_handle)
+                mother = self._db.get_person_from_handle(m_handle)
+                fcount = 0
+                mcount = 0
+                family_list = father.get_parent_family_handle_list()
+                for fam_handle in family_list:
+                    family = self._db.get_family_from_handle(fam_handle)
+                    if family is not None:
+                        fcount = fcount + 1
+                family_list = mother.get_parent_family_handle_list()
+                for fam_handle in family_list:
+                    family = self._db.get_family_from_handle(fam_handle)
+                    if family is not None:
+                        mcount = mcount + 1
+                first = father
+                second = mother
+                if fcount < mcount:
+                    first = mother
+                    second = father
+                self.doc.add_link(first.get_gramps_id(),
+                                  second.get_gramps_id(),
+                                  "invis",
+                                  "none",
+                                  "none")
+            if f_handle in self.persons:
                 father = self._db.get_person_from_handle(f_handle)
                 self.doc.add_link(father.get_gramps_id(),
                                   fam_id, "",
                                   self.arrowheadstyle,
                                   self.arrowtailstyle)
-            if m_handle:
+            if m_handle in self.persons:
                 mother = self._db.get_person_from_handle(m_handle)
                 self.doc.add_link(mother.get_gramps_id(),
                                   fam_id, "",
@@ -512,7 +546,7 @@ class RelGraphReport(Report):
 
         if gender == person.FEMALE and self.use_roundedcorners:
             style = "rounded"
-        elif gender == person.UNKNOWN:
+        elif gender == person.UNKNOWN and self.use_hexagons:
             shape = "hexagon"
 
         if person == self.center_person and self.increlname:
@@ -583,8 +617,7 @@ class RelGraphReport(Report):
 
         # at the very least, the label must have the person's name
         p_name = self._name_display.display(person)
-        p_name = p_name.replace('"', '&#34;')
-        label += p_name.replace('<', '&#60;').replace('>', '&#62;')
+        label += html.escape(p_name)
         p_id = person.get_gramps_id()
         if self.includeid == 1: # same line
             label += " (%s)" % p_id
@@ -597,7 +630,7 @@ class RelGraphReport(Report):
                 label += '%s(' % line_delimiter
                 if b_date:
                     label += '%s' % b_date
-                label += ' - '
+                label += ' – '
                 if d_date:
                     label += '%s' % d_date
                 label += ')'
@@ -608,7 +641,7 @@ class RelGraphReport(Report):
                 label += '%s(' % line_delimiter
                 if b_place:
                     label += '%s' % b_place
-                label += ' - '
+                label += ' – '
                 if d_place:
                     label += '%s' % d_place
                 label += ')'
@@ -718,10 +751,10 @@ class RelGraphReport(Report):
             event_date = event.get_date_object()
             if event_date.get_year_valid():
                 if self.event_choice in [4, 5]:
-                    return self._get_date( # localized year
+                    return self.get_date( # localized year
                         Date(event_date.get_year()))
                 elif self.event_choice in [1, 2, 3, 7]:
-                    return self._get_date(event_date)
+                    return self.get_date(event_date)
         return ''
 
     def get_place_string(self, event):
@@ -735,8 +768,11 @@ class RelGraphReport(Report):
         """
         if event and self.event_choice in [2, 3, 5, 6, 7]:
             place = _pd.display_event(self._db, event)
-            return place.replace('<', '&#60;').replace('>', '&#62;')
+            return html.escape(place)
         return ''
+    def get_date(self, date):
+        """ return a formatted date """
+        return html.escape(self._get_date(date))
 
 #------------------------------------------------------------------------
 #
@@ -796,6 +832,12 @@ class RelGraphOptions(MenuReportOptions):
                                   "between women and men."))
         add_option("useroundedcorners", roundedcorners)
 
+        # see bug report #11112
+        hexagons = BooleanOption(_("Use hexagons"), False)
+        hexagons.set_help(_("Use hexagons to differentiate "
+                                  "those of unknown gender."))
+        add_option("usehexagons", hexagons)
+
         stdoptions.add_gramps_id_option(menu, category_name, ownline=True)
 
         ################################
@@ -840,6 +882,11 @@ class RelGraphOptions(MenuReportOptions):
             _("Whether to include dates and/or places"))
         add_option("event_choice", self.event_choice)
 
+        show_family_leaves = BooleanOption(_("Show all family nodes"), True)
+        show_family_leaves.set_help(_("Show family nodes even if the output "
+                                      "contains only one member of the family."))
+        add_option("show_family_leaves", show_family_leaves)
+
         url = BooleanOption(_("Include URLs"), False)
         url.set_help(_("Include a URL in each graph node so "
                        "that PDF and imagemap files can be "
