@@ -65,7 +65,7 @@ from gramps.gui.merge import MergeCitation, MergeSource
 #
 #-------------------------------------------------------------------------
 from gramps.gen.const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.gettext
+_ = glocale.translation.sgettext
 
 #-------------------------------------------------------------------------
 #
@@ -78,16 +78,16 @@ class CitationTreeView(ListView):
     """
     # The data items here have to correspond, in order, to the items in
     # src/giu/views/treemodels/citationtreemodel.py
-    COL_TITLE_PAGE     =  0
-    COL_ID             =  1
-    COL_DATE           =  2
-    COL_CONFIDENCE     =  3
-    COL_PRIV           =  4
-    COL_TAGS           =  5
-    COL_CHAN           =  6
-    COL_SRC_AUTH       =  7
-    COL_SRC_ABBR       =  8
-    COL_SRC_PINFO      =  9
+    COL_TITLE_PAGE = 0
+    COL_ID = 1
+    COL_DATE = 2
+    COL_CONFIDENCE = 3
+    COL_PRIV = 4
+    COL_TAGS = 5
+    COL_CHAN = 6
+    COL_SRC_AUTH = 7
+    COL_SRC_ABBR = 8
+    COL_SRC_PINFO = 9
     # column definitions
     COLUMNS = [
         (_('Source: Title or Citation: Volume/Page'), TEXT, None),
@@ -147,12 +147,7 @@ class CitationTreeView(ListView):
             multiple=True,
             filter_class=SourceSidebarFilter)
 
-        self.func_list.update({
-            '<PRIMARY>J' : self.jump,
-            '<PRIMARY>BackSpace' : self.key_delete,
-            })
-
-        self.additional_uis.append(self.additional_ui())
+        self.additional_uis.append(self.additional_ui)
 
     # Override change_active from NavigationView, so that only Citations can be
     # put in the history list for the CitationTreeView
@@ -298,100 +293,241 @@ class CitationTreeView(ListView):
         """
         ListView.define_actions(self)
 
-        self._add_action('Add source', 'gramps-source', _("Add source..."),
-                         accel=None,
-                         tip=self.ADD_SOURCE_MSG,
-                         callback=self.add_source)
-        self._add_action('Add citation', 'gramps-citation',
-                         _("Add citation..."),
-                         accel=None,
-                         tip=self.ADD_CITATION_MSG,
-                         callback=self.share)
+        self.action_list.extend([
+            ('AddSource', self.add_source),
+            ('AddCitation', self.share),
+            ('OpenAllNodes', self.open_all_nodes),
+            ('CloseAllNodes', self.close_all_nodes), ])
 
-        self.all_action = Gtk.ActionGroup(name=self.title + "/CitationAll")
-        self.edit_action = Gtk.ActionGroup(name=self.title + "/CitationEdit")
+    additional_ui = [  # Defines the UI string for UIManager
+        '''
+      <placeholder id="LocalExport">
+        <item>
+          <attribute name="action">win.ExportTab</attribute>
+          <attribute name="label" translatable="yes">Export View...</attribute>
+        </item>
+      </placeholder>
+''',
+        '''
+      <section id="AddEditBook">
+        <item>
+          <attribute name="action">win.AddBook</attribute>
+          <attribute name="label" translatable="yes">_Add Bookmark</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.EditBook</attribute>
+          <attribute name="label" translatable="no">%s...</attribute>
+        </item>
+      </section>
+''' % _('Organize Bookmarks'),
+        '''
+      <placeholder id="CommonGo">
+      <section>
+        <item>
+          <attribute name="action">win.Back</attribute>
+          <attribute name="label" translatable="yes">_Back</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.Forward</attribute>
+          <attribute name="label" translatable="yes">_Forward</attribute>
+        </item>
+      </section>
+      </placeholder>
+''',
+        '''
+      <section id='CommonEdit' groups='RW'>
+        <item>
+          <attribute name="action">win.Add</attribute>
+          <attribute name="label" translatable="yes">_Add...</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.AddSource</attribute>
+          <attribute name="label" translatable="yes">Add source...</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.AddCitation</attribute>
+          <attribute name="label" translatable="yes">Add citation...</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.Edit</attribute>
+          <attribute name="label">%s</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.Remove</attribute>
+          <attribute name="label" translatable="yes">_Delete</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.Merge</attribute>
+          <attribute name="label" translatable="yes">_Merge...</attribute>
+        </item>
+      </section>
+''' % _("action|_Edit..."),  # to use sgettext()
+        '''
+        <placeholder id='otheredit'>
+        <item>
+          <attribute name="action">win.FilterEdit</attribute>
+          <attribute name="label" translatable="yes">'''
+        '''Citation Filter Editor</attribute>
+        </item>
+        </placeholder>
+''',  # Following are the Toolbar items
+        '''
+    <placeholder id='CommonNavigation'>
+    <child groups='RO'>
+      <object class="GtkToolButton">
+        <property name="icon-name">go-previous</property>
+        <property name="action-name">win.Back</property>
+        <property name="tooltip_text" translatable="yes">'''
+        '''Go to the previous object in the history</property>
+      </object>
+      <packing>
+        <property name="homogeneous">False</property>
+      </packing>
+    </child>
+    <child groups='RO'>
+      <object class="GtkToolButton">
+        <property name="icon-name">go-next</property>
+        <property name="action-name">win.Forward</property>
+        <property name="tooltip_text" translatable="yes">'''
+        '''Go to the next object in the history</property>
+      </object>
+      <packing>
+        <property name="homogeneous">False</property>
+      </packing>
+    </child>
+    </placeholder>
+''',
+        '''
+    <placeholder id='BarCommonEdit'>
+    <child groups='RW'>
+      <object class="GtkToolButton">
+        <property name="icon-name">list-add</property>
+        <property name="action-name">win.Add</property>
+        <property name="tooltip_text">%s</property>
+        <property name="label" translatable="yes">_Add...</property>
+        <property name="use-underline">True</property>
+      </object>
+      <packing>
+        <property name="homogeneous">False</property>
+      </packing>
+    </child>
+    <child groups='RW'>
+      <object class="GtkToolButton">
+        <property name="icon-name">gramps-source</property>
+        <property name="action-name">win.AddSource</property>
+        <property name="tooltip_text">%s</property>
+        <property name="label" translatable="yes">Add source...</property>
+      </object>
+      <packing>
+        <property name="homogeneous">False</property>
+      </packing>
+    </child>
+    <child groups='RW'>
+      <object class="GtkToolButton">
+        <property name="icon-name">gramps-citation</property>
+        <property name="action-name">win.AddCitation</property>
+        <property name="tooltip_text">%s</property>
+        <property name="label" translatable="yes">Add citation...</property>
+      </object>
+      <packing>
+        <property name="homogeneous">False</property>
+      </packing>
+    </child>
+    <child groups='RW'>
+      <object class="GtkToolButton">
+        <property name="icon-name">gtk-edit</property>
+        <property name="action-name">win.Edit</property>
+        <property name="tooltip_text">%s</property>
+        <property name="label" translatable="yes">Edit...</property>
+        <property name="use-underline">True</property>
+      </object>
+      <packing>
+        <property name="homogeneous">False</property>
+      </packing>
+    </child>
+    <child groups='RW'>
+      <object class="GtkToolButton">
+        <property name="icon-name">list-remove</property>
+        <property name="action-name">win.Remove</property>
+        <property name="tooltip_text">%s</property>
+        <property name="label" translatable="yes">_Delete</property>
+        <property name="use-underline">True</property>
+      </object>
+      <packing>
+        <property name="homogeneous">False</property>
+      </packing>
+    </child>
+    <child groups='RW'>
+      <object class="GtkToolButton">
+        <property name="icon-name">gramps-merge</property>
+        <property name="action-name">win.Merge</property>
+        <property name="tooltip_text">%s</property>
+        <property name="label" translatable="yes">_Merge...</property>
+        <property name="use-underline">True</property>
+      </object>
+      <packing>
+        <property name="homogeneous">False</property>
+      </packing>
+    </child>
+    </placeholder>
+''' % (ADD_MSG, ADD_SOURCE_MSG, ADD_CITATION_MSG, EDIT_MSG, DEL_MSG,
+            MERGE_MSG),
+        '''
+    <menu id="Popup">
+      <section>
+        <item>
+          <attribute name="action">win.Back</attribute>
+          <attribute name="label" translatable="yes">_Back</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.Forward</attribute>
+          <attribute name="label" translatable="yes">Forward</attribute>
+        </item>
+      </section>
+      <section id="PopUpTree">
+        <item>
+          <attribute name="action">win.OpenAllNodes</attribute>
+          <attribute name="label" translatable="yes">'''
+        '''Expand all Nodes</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.CloseAllNodes</attribute>
+          <attribute name="label" translatable="yes">'''
+        '''Collapse all Nodes</attribute>
+        </item>
+      </section>
+       <section>
+        <item>
+          <attribute name="action">win.Add</attribute>
+          <attribute name="label" translatable="yes">_Add...</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.AddCitation</attribute>
+          <attribute name="label" translatable="yes">'''
+        '''Add citation...</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.Edit</attribute>
+          <attribute name="label">%s</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.Remove</attribute>
+          <attribute name="label" translatable="yes">_Delete</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.Merge</attribute>
+          <attribute name="label" translatable="yes">_Merge...</attribute>
+        </item>
+      </section>
+      <section>
+        <placeholder id='QuickReport'>
+        </placeholder>
+      </section>
+    </menu>
+''' % _('action|_Edit...')  # to use sgettext()
+]
 
-        self._add_action('FilterEdit', None, _('Citation Filter Editor'),
-                         callback=self.filter_editor,)
-        self._add_action('QuickReport', None, _("Quick View"), None, None, None)
-
-        self._add_action_group(self.edit_action)
-        self._add_action_group(self.all_action)
-
-        self.all_action.add_actions([
-                ('OpenAllNodes', None, _("Expand all Nodes"), None, None,
-                 self.open_all_nodes),
-                ('CloseAllNodes', None, _("Collapse all Nodes"), None, None,
-                 self.close_all_nodes),
-                ])
-
-    def additional_ui(self):
-        """
-        Defines the UI string for UIManager
-        """
-        return '''<ui>
-          <menubar name="MenuBar">
-            <menu action="FileMenu">
-              <placeholder name="LocalExport">
-                <menuitem action="ExportTab"/>
-              </placeholder>
-            </menu>
-            <menu action="BookMenu">
-              <placeholder name="AddEditBook">
-                <menuitem action="AddBook"/>
-                <menuitem action="EditBook"/>
-              </placeholder>
-            </menu>
-            <menu action="GoMenu">
-              <placeholder name="CommonGo">
-                <menuitem action="Back"/>
-                <menuitem action="Forward"/>
-              </placeholder>
-            </menu>
-            <menu action="EditMenu">
-              <placeholder name="CommonEdit">
-                <menuitem action="Add"/>
-                <menuitem action="Add source"/>
-                <menuitem action="Add citation"/>
-                <menuitem action="Edit"/>
-                <menuitem action="Remove"/>
-                <menuitem action="Merge"/>
-             </placeholder>
-              <menuitem action="FilterEdit"/>
-            </menu>
-          </menubar>
-          <toolbar name="ToolBar">
-            <placeholder name="CommonNavigation">
-              <toolitem action="Back"/>
-              <toolitem action="Forward"/>
-            </placeholder>
-            <placeholder name="CommonEdit">
-              <toolitem action="Add"/>
-              <toolitem action="Add source"/>
-              <toolitem action="Add citation"/>
-              <toolitem action="Edit"/>
-              <toolitem action="Remove"/>
-              <toolitem action="Merge"/>
-            </placeholder>
-          </toolbar>
-          <popup name="Popup">
-            <menuitem action="Back"/>
-            <menuitem action="Forward"/>
-            <separator/>
-            <menuitem action="OpenAllNodes"/>
-            <menuitem action="CloseAllNodes"/>
-            <separator/>
-            <menuitem action="Add"/>
-            <menuitem action="Add citation"/>
-            <menuitem action="Edit"/>
-            <menuitem action="Remove"/>
-            <menuitem action="Merge"/>
-            <separator/>
-            <menu name="QuickReport" action="QuickReport"/>
-          </popup>
-        </ui>'''
-
-    def add_source(self, obj):
+    def add_source(self, *obj):
         """
         add_source: Add a new source (this is also available from the
                       source view)
@@ -412,7 +548,7 @@ class CitationTreeView(ListView):
         except WindowActiveError:
             pass
 
-    def add(self, obj):
+    def add(self, *obj):
         """
         add:        Add a new citation and a new source (this can also be done
                       by source view add a source, then citation view add a new
@@ -435,7 +571,7 @@ class CitationTreeView(ListView):
         except WindowActiveError:
             pass
 
-    def share(self, obj):
+    def share(self, *obj):
         """
         share:      Add a new citation to an existing source (when a source is
                       selected)
@@ -455,7 +591,7 @@ class CitationTreeView(ListView):
                               self.__blocked_text(),
                               parent=self.uistate.window)
 #
-    def remove(self, obj):
+    def remove(self, *obj):
         self.remove_selected_objects()
 
     def remove_object_from_handle(self, handle):
@@ -477,7 +613,7 @@ class CitationTreeView(ListView):
             is_used = any(the_lists)
             return (query, is_used, source)
 
-    def edit(self, obj):
+    def edit(self, *obj):
         """
         Edit either a Source or a Citation, depending on user selection
         """
@@ -518,7 +654,7 @@ class CitationTreeView(ListView):
                     "source is being edited.\n\nTo edit this "
                     "source, you need to close the object.")
 
-    def merge(self, obj):
+    def merge(self, *obj):
         """
         Merge the selected citations.
         """
